.. _technical_reference:

===================
Technical Reference
===================

Model
=====
The :ref:`Model <model documentation>` section first presents the :ref:`inputs and variable dimensions <input>` documentation. 
In a second time, it explains the calculations of the model through the method docstrings in the simulation order.
The model is explained in three differents details levels from the less detailed to the more detailed : 

- :ref:`High level documentation <high_level_doc>`
- :ref:`Low level documentation <low_level_doc>`

API reference
=============
The :ref:`API reference<api_reference>` section classically documents the various modules of the project using Sphinx's automatic generation.

.. toctree::
   :maxdepth: 1
   :hidden:

   model/index
   api/index